@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-#NOQA
-
 """Providers configuration.
 
 List here the video providers that should be used to match a video.
@@ -11,8 +9,8 @@ List here the video providers that should be used to match a video.
 
 PROVIDERS = {
     'youtube': {
-        'link_template': r"""http://www.youtube.com/embed/{video_id}""",
-        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0" allowfullscreen="true" autoPlay="1" related="0"></iframe>""",
+        'link_template': r"""http://www.youtube.com/embed/{video_id}?autoPlay=1&related=0""",
+        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0"></iframe>""",
         'validation_template': r"""http://www.youtube.com/watch?v={video_id}""",
         'matches': [
             r"""youtube.[^/]+/v/([^\\"'/&?@]+)""",
@@ -20,8 +18,8 @@ PROVIDERS = {
         ]
     },
     'vimeo': {
-        'link_template': r"""http://player.vimeo.com/video/{video_id}""",
-        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0" allowfullscreen="true" autoPlay="1" related="0"></iframe>""",
+        'link_template': r"""http://player.vimeo.com/video/{video_id}?autoPlay=1&related=0""",
+        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0"></iframe>""",
         'validation_template': r"""http://vimeo.com/{video_id}""",
         'matches': [
             r"""vimeo.[^/]+/video/([^\\"'/&?@]+)""",
@@ -29,7 +27,7 @@ PROVIDERS = {
         ]
     },
     'google': {
-        'link_template': r"""http://video.google.com/googleplayer.swf?docId={video_id}""",
+        'link_template': r"""http://video.google.com/googleplayer.swf?docId={video_id}&autoPlay=1&related=0""",
         'embed_template': r"""<embed id=VideoPlayback src="{video_link}" style="width:480px;height:395px" allowfullscreen="true" allowScriptAccess=always type=application/x-shockwave-flash> </embed>""",
         'validation_template': r"""http://video.google.com/videoplay?docid={video_id}""",
         'matches': [
@@ -37,8 +35,8 @@ PROVIDERS = {
         ]
     },
     'dailymotion': {
-        'link_template': r"""http://www.dailymotion.com/embed/video/{video_id}""",
-        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0" allowfullscreen="true" autoPlay="1" related="0"></iframe>""",
+        'link_template': r"""http://www.dailymotion.com/embed/video/{video_id}?autoPlay=1&related=0""",
+        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0"></iframe>""",
         'validation_template': r"""http://www.dailymotion.com/video/{video_id}""",
         'matches': [
             r"""dailymotion.[^/]+/swf/video/([^\\"'/&?@]+)""",
@@ -47,8 +45,8 @@ PROVIDERS = {
         ]
     },
     'crosstv': {
-        'link_template': r"""http://embed.cdn01.net/player.php?width=640&height=360&tvButtonID=crosstv&id={video_id}""",
-        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0" allowfullscreen="true" autoPlay="1" related="0"></iframe>""",
+        'link_template': r"""http://embed.cdn01.net/player.php?width=640&height=360&tvButtonID=crosstv&autoPlay=1&related=0&id={video_id}""",
+        'embed_template': r"""<iframe width="480" height="395" src="{video_link}" frameborder="0"></iframe>""",
         'validation_template': r"""http://embed.cdn01.net/player.php?width=640&height=360&tvButtonID=crosstv&id={video_id}""",
         'matches': [
             r"""embed.cdn01.[^/]+/player.php\?.*?&id=([^\\"'/&?@]+)""",
